/*******************************************************************************
 * Copyright (c) Lenovo 2020.
 *
 *  LIMITED AND RESTRICTED RIGHTS NOTICE: If data or software is delivered
 *  pursuant a General Services Administration (GSA) contract, use, reproduction, or
 *  disclosure is subject to restrictions set forth in Contract No. GS-35F-05925.
 ******************************************************************************/
import { ChangeDetectorRef, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { ExtendedDatePipe } from '../../pipes/extended-date/extended-date.pipe';
import { Subscription } from 'rxjs';
import AlertAnalyticsCardLabels from './alert-analytics-card-labels';
import * as i0 from "@angular/core";
export declare class AlertsAnalyticsCardComponent implements OnChanges {
    private cdr;
    private extendedDatePipe;
    /** Data received from server */
    data: any;
    historyChartOptions: any;
    doughnutChartOptions: any;
    historyChartInstance: any;
    doughnutChartInstance: any;
    analyticsLicense: any;
    dates: Date[];
    selectedDayStatistics: {
        day: string;
        states: {
            type: string;
            count: number;
            statisticsCount: number;
            typeStr: string;
        }[];
    };
    loading: boolean;
    noDaysPossibleValues: number[];
    selectedNoOfDays: number;
    subscription: Subscription;
    analyticsCardIconConfig: any;
    labels: AlertAnalyticsCardLabels;
    chartData: any;
    noData: EventEmitter<boolean>;
    onStatisticsTypeChange: EventEmitter<any>;
    onNoDaysChange: EventEmitter<any>;
    STATISTICS_TYPES: {
        value: 'severity' | 'sourceType' | 'service' | 'resourceType';
        label: string;
    }[];
    selectedStatisticsType: {
        value: 'severity' | 'sourceType' | 'service' | 'resourceType';
        label: string;
    };
    constructor(cdr: ChangeDetectorRef, extendedDatePipe: ExtendedDatePipe);
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    getAnalyticsLicense(): any;
    getStatistics(): void;
    initializeData(): void;
    onHistoryChartInit(ec: any): void;
    onDoughnutChartInit(ec: any): void;
    /**
     * Display the details for the hovered day on the right side of the card
     */
    onChartMouseOver(ev: any): void;
    getDayAggregatedInformation(properties: {
        type: string;
        typeStr: string;
    }[], historyEntry: any): void;
    setSelectedNoDays(noDays: number): void;
    setStatisticsType(statisticsType: {
        value: 'severity' | 'sourceType' | 'service' | 'resourceType';
        label: string;
    }): void;
    getPropertiesFromStates(): {
        type: string;
        typeStr: string;
    }[];
    renderLayout(): void;
    createCharts(): void;
    tooltipFormatterFunction(index: number): void;
    /**
     * Configure the chart data series based on the statistics type
     * @param properties array of properties which matches the states type properties
     *
     * severity = `['Critical', 'Warning', 'Informational']`
     *
     * service = `['None', 'User', 'Serviceable']`
     *
     * resourceType = `['Chassis', 'Server', 'LXCA', 'LXCO', 'Storage', 'Switch', 'Rack PDU']`
     *
     * sourceType = `['Analytics', 'Device', 'Management']`
     *
     *
     * @param unlabeledSeriesEntryIndex in order to emphasize the gray area in the chart in case of unknown values the unlabeled series index is used
     * @param doughnutChartOptions chart options containing title options and colour options for each property (see `doughnut-charts-options.ts`)
     */
    configureDoughnutChartSeries(properties: {
        type: string;
        typeStr: string;
    }[], unlabeledSeriesEntryIndex: number, doughnutChartOptions: any): void;
    /**
     * Create the history chart data series and options based on the statistics type
     * @param properties array of properties which matches the states type properties
     *
     * severity = `['Critical', 'Warning', 'Informational']`
     *
     * service = `['None', 'User', 'Serviceable']`
     *
     * resourceType = `['Chassis', 'Server', 'LXCA', 'LXCO', 'Storage', 'Switch']`
     *
     * sourceType = `['Analytics', 'Device', 'Management']`
     *
     */
    createHistoryChart(properties: {
        type: string;
        typeStr: string;
    }[], chartOptions: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AlertsAnalyticsCardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AlertsAnalyticsCardComponent, "alerts-analytics-card", never, { "labels": "labels"; "chartData": "chartData"; }, { "noData": "noData"; "onStatisticsTypeChange": "onStatisticsTypeChange"; "onNoDaysChange": "onNoDaysChange"; }, never, never>;
}
