/*******************************************************************************
 * Copyright (c) Lenovo 2020.
 *
 *  LIMITED AND RESTRICTED RIGHTS NOTICE: If data or software is delivered
 *  pursuant a General Services Administration (GSA) contract, use, reproduction, or
 *  disclosure is subject to restrictions set forth in Contract No. GS-35F-05925.
 ******************************************************************************/
import { ElementRef, OnInit, OnChanges, SimpleChanges } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * In order to use the loading directive there are few conditions which need to be considered:
 *
 * The item which receives the directive MUST have a parent element and that parent element MUST have an id.
 *
 * Reason: The spinner is added as a child of the parent element because the element which gets the directive must have the opacity set to 0.3 and we don't
 * want that to affect the spinner so the spinner must be on the same level as the child elements which uses the directive, in most cases the <div class="card"> element
 * but the directive can be used also on other elements (see user groups page) if the condition presented above will be respected.
 */
export declare class LoadingDirective implements OnInit, OnChanges {
    private el;
    interval: any;
    loading: boolean;
    progress: string;
    showProgress: boolean;
    importProgressMessage: string;
    /**
     * When adding the importProgressMessage, it may happen that if the message is too long to  be displayed outside the borders of the modal.
     * Set this property if you want to maximize the modal with spacerSizePx number of pixels
     */
    spacerSizePx: number;
    constructor(el: ElementRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    addLoadingSpinner(): void;
    createSpanForProgress(): void;
    removeLoadingSpinner(): void;
    /**
     * Because the spinner is used also on the tables, when the request is done the table will change its size and that will affect other spinners.
     * Because of that, we need to recalculate the position of the spinners.
     */
    resetPositionOfLoadingSpinners(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<LoadingDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<LoadingDirective, "[loading]", never, { "loading": "loading"; "progress": "progress"; "showProgress": "showProgress"; "importProgressMessage": "importProgressMessage"; "spacerSizePx": "spacerSizePx"; }, {}, never>;
}
