export declare class TreeNode {
    /**
     * Data to store in each node
     * On the first level we have the actual row (because the code is the same with the ngxDatatableComponent and it is difficult to use another property for row)
     * and in the treeNodeProperties object we have properties specific to the tree structure
     *
     * For a job a treeNode object will be like so:
     * {
     *    name: 'Name of the job',
     *    status: 'Complete'
     *    start: new Date(),
     *    complete: new Date(),
     *    targets: 'something',
     *    percentage: 100,
     *    children: TreeNode[]
     *    // The below ones are tree related properties and they are being set in the ngx-treetable component
     *    expanded: false // expansion for mobile view
     *    level: 0,
     *    childrenExpansion: false // Only initially
     *    parent: TreeNode
     * }
     */
    [key: string]: any;
    /** The tree node specific properties */
    /** Children of the node */
    children?: TreeNode[];
    /** Boolean indicating if the row details should be displayed */
    expanded?: boolean;
    /** Level of the node in the tree */
    level?: number;
    /** Boolean indicating if the node should be expanded to show the children */
    childrenExpansion?: boolean;
    indeterminate?: boolean;
}
