import { SortingAndFilteringParamsBuilder } from '../../classes/sortingFilteringUtils/sortingFilteringUtils';
import { UiSettings, PageSetting, ColumnSetting, PaginationInfo, LocalStorageFilter } from './localStorageItems';
import * as i0 from "@angular/core";
export declare class LocalStorageService {
    constructor();
    retrievePaginationInfoDataWithBuilder(pageName: string): [
        number,
        number,
        SortingAndFilteringParamsBuilder,
        string | undefined,
        'asc' | 'desc' | undefined
    ] | undefined;
    retrievePaginationInfoDataWithoutBuilder(pageName: string): [number, number, string | undefined, 'asc' | 'desc' | undefined] | undefined;
    createPaginationInfoBasedOnData(offset: number, limit: number, builder: SortingAndFilteringParamsBuilder, sortField?: string, sortMode?: 'asc' | 'desc'): PaginationInfo;
    /**
     * Method used to retrieve all uiSettings and specific page settings from local storage or session storage
     * @param pageName
     * @param storageType use 'session' for session storage and 'local' for local storage
     */
    getUiSettingsFromStorage(pageName: string, storageType: 'session' | 'local'): [UiSettings | undefined, PageSetting | any];
    updateSessionStorageColumnSettings(pageName: string, columnSettings: ColumnSetting[]): void;
    updateSessionStorageTablePaginationSettings(pageName: string, paginationInfo: PaginationInfo): void;
    /**
     * Method used to initialize page settings for a specific page in local storage or session storage
     * @param pageName
     * @param storageType use 'session' for session storage and 'local' for local storage
     */
    initializePageSettingsInStorage(pageName: string, storageType: 'session' | 'local'): void;
    getLimit(pageName: string, storageType: 'session' | 'local'): number;
    getOffset(pageName: string, storageType: 'session' | 'local'): number;
    /**
     * Method which saves the active filtering configuration in local storage based on username and page name
     * @param currentUsername
     * @param filter
     * @param pageName
     * @param replace if the user clicks the 'Save as' button replace should be false, otherwise the user wants to replace an existing filter
     */
    saveFilterForCurrentUser(currentUsername: string, filter: LocalStorageFilter, pageName: string, replace?: boolean): void;
    /**
     * Method used to check if a user can be saved as the entered username
     * @param currentUsername
     * @param pageName
     * @param filterName
     */
    checkIfFilterWithSameNameExists(currentUsername: string, pageName: string, filterName: string): boolean;
    removeFilter(currentUsername: string, pageName: string, filterName: string): boolean;
    getLanguage(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<LocalStorageService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LocalStorageService>;
}
